@@ -4,7 +4,7 @@ from django.conf.urls.defaults import patterns
 from django.conf.urls.defaults import url
 from django.conf.urls.static import static
 from django.contrib import admin
-from django.contrib.staticfiles.urls import staticfiles_urlpatterns
+from staticfiles.urls import staticfiles_urlpatterns
 
 import lizard_ui.configchecker
 import lizard_ui.views
@@ -48,6 +48,8 @@ if settings.DEBUG:  # Pragma: nocover
          {'template': 'lizard_ui/example.html'}),
         (r'^examples/textual/$', 'direct_to_template',
          {'template': 'lizard_ui/example-textual.html'}),
+        (r'^examples/table/$', 'direct_to_template',
+         {'template': 'lizard_ui/example-table.html'}),
         (r'^examples/images/$', 'direct_to_template',
          {'template': 'lizard_ui/example-images.html'}),
         (r'^examples/tree/$', 'direct_to_template',
